@@ -35,6 +35,10 @@ def merge_np(doc):
 			retokenizer.merge(np, attrs=attrs) 
 	return doc
 
+def skenp(doc, tag="_NP"): # added 2022.3.22, for skevec
+	merge_np(doc) # transform doc , finally to be called 
+	return " ".join([tag if t.ent_type_ == 'NP' else t.text for t in doc])
+
 def merge_n_of_n(doc):
 	if not hasattr(merge_n_of_n, 'matcher'):
 		merge_n_of_n.matcher = Matcher(spacy.nlp.vocab)
