@@ -321,14 +321,14 @@ PUT index
 
 POST index/_doc
 {
- "image-vector": [0.12, 1.34, 3,4]
+ "image-vector": [0.12, 1.34, 3.4]
 }
 
 GET index/_knn_search
 {
  "knn": {
    "field": "image-vector",
-   "query_vector": [-0.5, 9.4, ...],
+   "query_vector": [-0.5, 9.4, 3],
    "k": 10,
    "num_candidates": 100
  }
